//
// gt_calls.h
//
// Pre-definitions for various routines
//
// Copyright (c) 2001, Grenville Armitage
// gj_armitage@yahoo.com
//
//
// +++++++++++++++++++++++ License and Conditions +++++++++++++++++++++++++
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   A copy of this license was supplied with pkthisto in the
//   file ../COPYING. Alternatively, a copy may be obtained from
//   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
//   Boston, MA  02111-1307, USA.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++


// Startup/initialization routines

void parse_config_file(struct global_state *gs,
					   char *configfile);

void parse_config_line(struct global_state *gs,
					   char *line);

int sanity_check_config(struct global_state *gs);

void print_operating_config(struct global_state *gs);

//
// Reading trace file records
//

void read_tracefiles(struct global_state *gs);

// Reading tcpdump tracefile records

void read_tcpdump_file(struct global_state *gs);

int parse_tcpdmp_record(struct global_state *gs,
						struct packet_header *frm);

// Reading NAI Sniffer tracefile records

void read_naisniffer_file(struct global_state *gs);

int parse_nai_version_record(struct global_state *gs,
							 int *tscale,
							 long *baset);

int parse_nai_frame_record(struct global_state *gs,
							 int *tscale,
							 long baset);

//
// Real-time local host packet capture routines
//

void do_packetsnoop(struct global_state *gs);

int init_bpf(struct global_state *gs);


//
// Signal handler routines
//

void init_sighandler(struct global_state *gs);

void usr1_sighandler(int x);

void term_sighandler(int x);

//
// Updating flow records
//
// add_pkt_record() is the primary interface between
// the link/tracefile-specific routines, and the statistics
// gathering routines. it is called with a pointer to an
// abstract packet record (struct pkt_record)
//

void gts_add_pkt_record(struct global_state *gs,
						struct pkt_record *prec);

int gts_init_srv_flows(struct global_state *gs,
						 struct seen_flow *seenf,
						 struct pkt_record *prec);

void gts_check_srv_flows(struct global_state *gs,
						 struct seen_flow *seenf,
						 struct pkt_record *prec);

void gts_add_flow_record(struct global_state *gs,
					 struct pkt_record *prec,
					 struct seen_flow *seenf);

void gt_flowstop_event(struct global_state *gs,
						struct seen_flow *seenf,
						long t_sec,
						long t_usec);

void gt_flowstart_event(struct global_state *gs,
						struct seen_flow *seenf,
						long t_sec,
						long t_usec);

void gt_flow_established(struct global_state *gs,
						struct seen_flow *seenf);

void gts_check_idle_flows(struct global_state *gs,
						  long sec,
						  long usec);

//
// Updating packet histograms
//
void update_plen_histo(struct global_state *gs,
					   struct pkt_record *prec,
					   struct seen_flow *seenf,
					   __int64 newtime,
					   int flag);


//
// Updating inter-arrival histograms
//

void update_arrival_histo(struct global_state *gs,
					   struct pkt_record *prec,
					   struct seen_flow *seenf,
					   __int64 newtime,
					   int flag);


//
// Post-analysis routines
//

void print_statistics(struct global_state *gs);

void print_flow_stats(struct global_state *gs,
					  struct seen_flow *seenf);

void calculate_wasted_space(struct global_state *gs);


//
// Checkpointing routines
//

void gts_checkpoint_stats(struct global_state *gs,
					  int mode);

void gts_checkpoint_seenf(struct global_state *gs,
					  struct seen_flow *seenf,
					  int mode);

void gt_sort_flow_histos(struct global_state *gs,
						 struct seen_flow *seenf,
						 int mode);

void gts_ascii_lenhisto(struct global_state *gs,
						struct len_histo *tmp_lenh,
						FILE *flh,
						FILE *fclh,
						int *low,
						int *mid,
						int *hi);
						
void gts_compressed_lenhisto(struct global_state *gs,
						struct len_histo *tmp_lenh,
						FILE *flh,
						FILE *fclh,
						int *low,
						int *mid,
						int *hi);
					
void gts_ascii_interhisto(struct global_state *gs,
						struct inter_histo *tmp_interh,
						FILE *fih,
						FILE *fcih);
						
void gts_compressed_interhisto(struct global_state *gs,
						struct inter_histo *tmp_interh,
						FILE *fih,
						FILE *fcih);
		
void gts_convertfile(char *file);

int gts_convert_oneline(char *string,
					int num,
					int *array);
