//
// gt_defines.h
//
// constants and macros
//
// Copyright (c) 2001, Grenville Armitage
// gj_armitage@yahoo.com
//
//
// +++++++++++++++++++++++ License and Conditions +++++++++++++++++++++++++
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   A copy of this license was supplied with pkthisto in the
//   file ../COPYING. Alternatively, a copy may be obtained from
//   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
//   Boston, MA  02111-1307, USA.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

#define PH_VERSION "0.1.2\0"

// Originally developed this code under Win32 VisualC++6.0
// so need to re-define some tokens for *nix gcc
//
#ifndef WIN32
#define __int64 __int64_t
#define _read read
#define _open open
#define _O_RDONLY O_RDONLY
// Win32 requires open() to bitwise-OR a flag to specify
// text or binary translation on file read()s. Under gcc
// file access through open()/read() is always binary.
// Define _O_BINARY to be harmless.
#define _O_BINARY 0
#endif


#define DEBUG(W, Z,X)	if ((int)(W->debug) >= Z) printf X

#define FLAG_SET(X,Y)	((X & Y) == Y)
#define FLAG_UNSET(X,Y)	((X & Y) == 0)

#define OUTFDEFAULT	"gtout\0"
#define CONFDEFAULT	"conf_ph.txt\0"

#define FLOW_MAX_MS_DEFAULT		500	// A flow stops if pkts not seen for X milliseconds
#define MIN_FLOW_MAX_MS			10	// User can configure how short an interval is
									// considered 'stopped' for a flow, but not below
									// this value in milliseconds. 

#define PKT_PER_HISTO_DEFAULT	1000// Each flow starts a new histogram
									// after X packets flow
#define PKT_CNT_MIN_DEFAULT		100	// When printing out results, don't dump
									// histograms containing less that X pkts

#define PKT_SIZE_MIN			38	// Min num of bytes of Ether+IP+UDP
									// frame needed for flow identification

#define CHKPOINTINTERVAL		3600 // Default is to checkpoint every 60 minutes

#define CHKP_INTERIM			1
#define CHKP_FINAL				2

#define NO_SERVER				0
#define TO_SERVER				16
#define FROM_SERVER				32

// Sizes for histogram arrays

#define MAX_INTERARRIVAL 1000	// Inter-arrival histo has this many buckets
#define INTERHISTOWIDTH 250		// Inter-arrival histo buckets are X usec wide
#define MAX_LENGTH		800		// Length histo has this many buckets
#define LENHISTOWIDTH	1		// Length histo buckets are X bytes wide

// Constants for 'stats' flags

#define SNIFFER			1	// Source file is in NAI Sniffer format
#define TCPDUMP			2	// Source file is in tcpdump format
#define FILE_STATS		4	// Log the tracefile stats to the output file
#define PKTSNOOP		8	// Source is local host real-time packet capture
#define DOSIZES			16	// Create low/mid/upper/ratio SIZE checkpoint files
							// (default is NOT)
#define NOPROMISC		32	// Do NOT open capture device in promiscuous mode
#define COMPRESS_ASCII	64	// Dump histograms using compressed ASCII encoding
							// rather than pure ASCII xgraph-style encodings.


// Constants for per-flow/per-histo state

#define F_INIT		1	// Flow has been detected, but pkts < gs->pkt_cnt_min
#define F_ESTAB		2	// At least gs->pkt_cnt_min packets have been seen
#define F_STOPPED	4	// This histo instance of a flow stopped and later resume
						// (the subsequent data is in the next histo)
#define F_FILEOPEN	8	// The output files for this flow have already been opened
						// (so subsequent accesses should re-open to *append* data)

