//
// gt_sniffer_hdr.h
//
// structures relating to parsing network associate's
// 'sniffer' program trace files
//
// Copyright (c) 2001, Grenville Armitage
// gj_armitage@yahoo.com
//
//
// +++++++++++++++++++++++ License and Conditions +++++++++++++++++++++++++
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   A copy of this license was supplied with pkthisto in the
//   file ../COPYING. Alternatively, a copy may be obtained from
//   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
//   Boston, MA  02111-1307, USA.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

// Note: 'short' is assumed to be 2 octets in the following
// structures.

// Standard record header

struct f_rec_struct {
	short type;			// Record type
	short length;		// Length of remainder of this record. */
	short rsvd;			// Empty word, null.
};

// Record type values

#define REC_VERS	 1 // Version record (f_vers)
#define REC_FRAME2	 4 // Frame data (f_frame2)
#define REC_EOF		 3 // End-of-file record (no data follows)


struct date_struct {
	unsigned short time;
	unsigned short date;
};

// Tracefile version/status record

struct f_vers_struct {
	short maj_vers;			// Major version of Sniffer that made this tracefile
	short min_vers;			// Minor version
	unsigned char date[4];	// Date & time (4 bytes, DOS format)
	unsigned char type;		// What type of records follow
	unsigned char network;	// Link layer type indication
	unsigned char format;	// An indicator of the format version. */
	unsigned char timeunit;	// An indicator of the frame timestamp unit.*/
	unsigned char cmprs_ver;  // An indicator of compression version. */
	unsigned char cmprs_level;// An indicator of compression level. */
	char rsvd[4];			// Empty four octets
};


// Value of f_vers_struct->network if link is Ethernet

#define NETWORK_ENET 1 // Ethernet

// Recognized value of f_vers_struct->timeunit

#define TIMEUNIT_2USEC	 4	// 2 microseconds per unit (this format
							// appears in my NAI sniffer tracefiles
							// of 100baseT traffic)
							
// Format of frame data record

struct f_frame2_struct {
	unsigned short time_low;	// Low time, network-dependent units
	unsigned short time_mid;	// Mid time, network-dependent units
	char time_high;				// High time, network-dependent units
	char time_day;				// Time in days since start of capture
	short size;					// Number of bytes actually written in this file
								// (may be less than frame's original length)
	char fs;					// Frame error status bits
	char flags;					// Buffer flags; for internal use
	short true_size;			// If nonzero, the size of the original frame
								// (since this frame has been truncated)
	short rsvd;					// Reserved; currently 0
	// The frame data follows
};

